# 2023-05-26 - Gauge Working Balance Helper

Deployment of the `GaugeWorkingBalanceHelper`, which reads the current and projected `working_balance` (effective veBAL boosted balance) for a user on a gauge, as well as the ratio of the `working_balance` to the supply. This can be used (e.g., by front-end processes) to determine whether checkpointing a gauge would be advantageous.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Polygon mainnet addresses](./output/polygon.json)
- [Arbitrum mainnet addresses](./output/arbitrum.json)
- [Optimism mainnet addresses](./output/optimism.json)
- [Gnosis mainnet addresses](./output/gnosis.json)
- [Avalanche mainnet addresses](./output/avalanche.json)
- [Polygon zkeVM mainnet addresses](./output/zkevm.json)
- [Base mainnet addresses](./output/base.json)
- [Goerli testnet addresses](./output/goerli.json)
- [Sepolia testnet addresses](./output/sepolia.json)
- [`GaugeWorkingBalanceHelper` artifact](./artifact/GaugeWorkingBalanceHelper.json)
